import CoreWLAN
from PyObjCTools.TestSupport import TestCase, min_os_level, os_level_between


class TestCWInterface(TestCase):
    @min_os_level("10.13")
    def testMethods10_13(self):
        self.assertArgIsBOOL(
            CoreWLAN.CWInterface.scanForNetworksWithName_includeHidden_error_, 1
        )
        self.assertArgIsOut(
            CoreWLAN.CWInterface.scanForNetworksWithName_includeHidden_error_, 2
        )

        self.assertArgIsBOOL(
            CoreWLAN.CWInterface.scanForNetworksWithSSID_includeHidden_error_, 1
        )
        self.assertArgIsOut(
            CoreWLAN.CWInterface.scanForNetworksWithSSID_includeHidden_error_, 2
        )

    @min_os_level("10.7")
    def test_methods10_7(self):
        self.assertResultIsBOOL(CoreWLAN.CWInterface.powerOn)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.deviceAttached)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.serviceActive)

        self.assertResultIsBOOL(CoreWLAN.CWInterface.setPower_error_)
        self.assertArgIsBOOL(CoreWLAN.CWInterface.setPower_error_, 0)
        self.assertArgIsOut(CoreWLAN.CWInterface.setPower_error_, 1)

        self.assertResultIsBOOL(CoreWLAN.CWInterface.setWLANChannel_error_)
        self.assertArgIsOut(CoreWLAN.CWInterface.setWLANChannel_error_, 1)

        self.assertResultIsBOOL(CoreWLAN.CWInterface.setPairwiseMasterKey_error_)
        self.assertArgIsOut(CoreWLAN.CWInterface.setPairwiseMasterKey_error_, 1)

        self.assertResultIsBOOL(CoreWLAN.CWInterface.setWEPKey_flags_index_error_)
        self.assertArgIsOut(CoreWLAN.CWInterface.setWEPKey_flags_index_error_, 3)

        self.assertArgIsOut(CoreWLAN.CWInterface.scanForNetworksWithSSID_error_, 1)
        self.assertArgIsOut(CoreWLAN.CWInterface.scanForNetworksWithName_error_, 1)

        self.assertResultIsBOOL(CoreWLAN.CWInterface.associateToNetwork_password_error_)
        self.assertArgIsOut(CoreWLAN.CWInterface.associateToNetwork_password_error_, 2)

        self.assertResultIsBOOL(
            CoreWLAN.CWInterface.associateToEnterpriseNetwork_identity_username_password_error_
        )
        self.assertArgIsOut(
            CoreWLAN.CWInterface.associateToEnterpriseNetwork_identity_username_password_error_,
            4,
        )

        self.assertResultIsBOOL(
            CoreWLAN.CWInterface.startIBSSModeWithSSID_security_channel_password_error_
        )
        self.assertArgIsOut(
            CoreWLAN.CWInterface.startIBSSModeWithSSID_security_channel_password_error_,
            4,
        )

        self.assertResultIsBOOL(
            CoreWLAN.CWInterface.commitConfiguration_authorization_error_
        )
        self.assertArgIsOut(
            CoreWLAN.CWInterface.commitConfiguration_authorization_error_, 2
        )

    @os_level_between("10.6", "10.8")
    def testMethods10_6(self):
        self.assertResultIsBOOL(CoreWLAN.CWInterface.supportsWoW)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.supportsWEP)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.supportsAES_CCM)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.supportsIBSS)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.supportsTKIP)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.supportsPMGT)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.supportsHostAP)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.supportsMonitorMode)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.supportsWPA)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.supportsWPA2)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.supportsWME)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.supportsShortGI40MHz)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.supportsShortGI20MHz)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.supportsTSN)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.power)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.powerSave)
        self.assertResultIsBOOL(CoreWLAN.CWInterface.isEqualToInterface_)

        self.assertResultIsBOOL(CoreWLAN.CWInterface.setChannel_error_)
        self.assertArgIsOut(CoreWLAN.CWInterface.setChannel_error_, 1)

        self.assertArgIsOut(
            CoreWLAN.CWInterface.scanForNetworksWithParameters_error_, 1
        )

        self.assertResultIsBOOL(
            CoreWLAN.CWInterface.associateToNetwork_parameters_error_
        )
        self.assertArgIsOut(
            CoreWLAN.CWInterface.associateToNetwork_parameters_error_, 2
        )

        self.assertResultIsBOOL(CoreWLAN.CWInterface.enableIBSSWithParameters_error_)
        self.assertArgIsOut(CoreWLAN.CWInterface.enableIBSSWithParameters_error_, 1)

        self.assertResultIsBOOL(CoreWLAN.CWInterface.commitConfiguration_error_)
        self.assertArgIsOut(CoreWLAN.CWInterface.commitConfiguration_error_, 1)



import CoreWLAN
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCoreWLANUtil(TestCase):
    @min_os_level("10.7")
    def testFunctions10_7(self):
        self.assertArgIsOut(CoreWLAN.CWKeychainCopyEAPUsernameAndPassword, 1)
        self.assertArgIsCFRetained(CoreWLAN.CWKeychainCopyEAPUsernameAndPassword, 1)
        self.assertArgIsOut(CoreWLAN.CWKeychainCopyEAPUsernameAndPassword, 2)
        self.assertArgIsCFRetained(CoreWLAN.CWKeychainCopyEAPUsernameAndPassword, 2)

        # Check it exists:
        CoreWLAN.CWKeychainSetEAPUsernameAndPassword
        CoreWLAN.CWKeychainDeleteEAPUsernameAndPassword
        CoreWLAN.CWKeychainSetEAPIdentity
        CoreWLAN.CWKeychainSetPassword
        CoreWLAN.CWKeychainDeletePassword
        CoreWLAN.CWMergeNetworks

        self.assertArgIsOut(CoreWLAN.CWKeychainCopyEAPIdentityList, 0)
        self.assertArgIsCFRetained(CoreWLAN.CWKeychainCopyEAPIdentityList, 0)

        self.assertArgIsOut(CoreWLAN.CWKeychainCopyEAPIdentity, 1)
        self.assertArgIsCFRetained(CoreWLAN.CWKeychainCopyEAPIdentity, 1)

        self.assertArgIsOut(CoreWLAN.CWKeychainCopyPassword, 1)
        self.assertArgIsCFRetained(CoreWLAN.CWKeychainCopyPassword, 1)

    @min_os_level("10.9")
    def testFunctions10_9(self):
        self.assertArgIsOut(CoreWLAN.CWKeychainFindWiFiPassword, 2)
        self.assertArgIsOut(CoreWLAN.CWKeychainFindWiFiEAPUsernameAndPassword, 2)
        self.assertArgIsOut(CoreWLAN.CWKeychainFindWiFiEAPUsernameAndPassword, 3)
        self.assertArgIsOut(CoreWLAN.CWKeychainCopyWiFiEAPIdentity, 2)
        self.assertArgIsCFRetained(CoreWLAN.CWKeychainCopyWiFiEAPIdentity, 2)

        CoreWLAN.CWKeychainSetWiFiPassword  # Only check existance
        CoreWLAN.CWKeychainDeleteWiFiPassword  # Only check existance
        CoreWLAN.CWKeychainSetWiFiEAPUsernameAndPassword  # Only check existance
        CoreWLAN.CWKeychainDeleteWiFiEAPUsernameAndPassword  # Only check existance
        CoreWLAN.CWKeychainSetWiFiEAPIdentity  # Only check existance



# This file is generated by objective.metadata
#
# Last update: Mon Mar 16 21:40:08 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$CWBSSIDDidChangeNotification$CWCountryCodeDidChangeNotification$CWErrorDomain$CWLinkDidChangeNotification$CWLinkQualityDidChangeNotification$CWLinkQualityNotificationRSSIKey$CWLinkQualityNotificationTransmitRateKey$CWModeDidChangeNotification$CWPowerDidChangeNotification$CWSSIDDidChangeNotification$CWScanCacheDidUpdateNotification$CWServiceDidChangeNotification$CoreWLANFrameworkVersionNumber@d$kCWAssocKey8021XProfile$kCWAssocKeyPassphrase$kCWBSSIDDidChangeNotification$kCWCountryCodeDidChangeNotification$kCWErrorDomain$kCWIBSSKeyChannel$kCWIBSSKeyPassphrase$kCWIBSSKeySSID$kCWLinkDidChangeNotification$kCWModeDidChangeNotification$kCWPowerDidChangeNotification$kCWSSIDDidChangeNotification$kCWScanKeyBSSID$kCWScanKeyDwellTime$kCWScanKeyMerge$kCWScanKeyRestTime$kCWScanKeySSID$kCWScanKeyScanType$"""
enums = """$CWEventTypeBSSIDDidChange@3$CWEventTypeCountryCodeDidChange@4$CWEventTypeLinkDidChange@5$CWEventTypeLinkQualityDidChange@6$CWEventTypeModeDidChange@7$CWEventTypeNone@0$CWEventTypePowerDidChange@1$CWEventTypeRangingReportEvent@10$CWEventTypeSSIDDidChange@2$CWEventTypeScanCacheUpdated@8$CWEventTypeVirtualInterfaceStateChanged@9$CoreWLANFrameworkVersionNumber2_0@200$kCWAPFullErr@-3913$kCWAssociationDeniedErr@-3909$kCWAuthAlgUnsupportedErr@-3910$kCWAuthenticationAlgorithmUnsupportedErr@-3910$kCWChallengeFailureErr@-3912$kCWChannelBand2GHz@1$kCWChannelBand5GHz@2$kCWChannelBandUnknown@0$kCWChannelWidth160MHz@4$kCWChannelWidth20MHz@1$kCWChannelWidth40MHz@2$kCWChannelWidth80MHz@3$kCWChannelWidthUnknown@0$kCWCipherKeyFlagsMulticast@4$kCWCipherKeyFlagsNone@0$kCWCipherKeyFlagsRx@16$kCWCipherKeyFlagsTx@8$kCWCipherKeyFlagsUnicast@2$kCWCipherSuiteRejectedErr@-3923$kCWDSSSOFDMUnsupportedErr@-3916$kCWEAPOLErr@1$kCWErr@-3931$kCWError@-3931$kCWFormatErr@-3904$kCWHTFeaturesNotSupported@-3926$kCWHTFeaturesNotSupportedErr@-3926$kCWIBSSModeSecurityNone@0$kCWIBSSModeSecurityWEP104@2$kCWIBSSModeSecurityWEP40@1$kCWIPCError@-3929$kCWIPCFailureErr@-3929$kCWInterfaceModeHostAP@3$kCWInterfaceModeIBSS@2$kCWInterfaceModeNone@0$kCWInterfaceModeStation@1$kCWInterfaceStateAssociating@3$kCWInterfaceStateAuthenticating@2$kCWInterfaceStateInactive@0$kCWInterfaceStateRunning@4$kCWInterfaceStateScanning@1$kCWInvalidAKMPErr@-3920$kCWInvalidAuthSeqNumErr@-3911$kCWInvalidAuthenticationSequenceNumberErr@-3911$kCWInvalidFormatErr@-3904$kCWInvalidGroupCipherErr@-3918$kCWInvalidInfoElementErr@-3917$kCWInvalidInformationElementErr@-3917$kCWInvalidPMKErr@-3924$kCWInvalidPairwiseCipherErr@-3919$kCWInvalidParameterErr@-3900$kCWInvalidRSNCapabilitiesErr@-3922$kCWKeychainDomainNone@0$kCWKeychainDomainSystem@2$kCWKeychainDomainUser@1$kCWNoErr@0$kCWNoMemErr@-3901$kCWNoMemoryErr@-3901$kCWNotSupportedErr@-3903$kCWOpModeHostAP@2$kCWOpModeIBSS@1$kCWOpModeMonitorMode@3$kCWOpModeStation@0$kCWOpNotPermitted@-3930$kCWOperationNotPermittedErr@-3930$kCWPCOTransitionTimeNotSupported@-3927$kCWPCOTransitionTimeNotSupportedErr@-3927$kCWPHYMode11A@0$kCWPHYMode11B@1$kCWPHYMode11G@2$kCWPHYMode11N@3$kCWPHYMode11a@1$kCWPHYMode11ac@5$kCWPHYMode11b@2$kCWPHYMode11g@3$kCWPHYMode11n@4$kCWPHYModeNone@0$kCWParamErr@-3900$kCWReassociationDeniedErr@-3908$kCWRefNotBoundErr@-3928$kCWReferenceNotBoundErr@-3928$kCWScanTypeActive@0$kCWScanTypeFast@2$kCWScanTypePassive@1$kCWSecurityDynamicWEP@6$kCWSecurityEnterprise@10$kCWSecurityModeDynamicWEP@4$kCWSecurityModeOpen@0$kCWSecurityModeWEP@1$kCWSecurityModeWPA2_Enterprise@6$kCWSecurityModeWPA2_PSK@3$kCWSecurityModeWPA_Enterprise@5$kCWSecurityModeWPA_PSK@2$kCWSecurityModeWPS@7$kCWSecurityNone@0$kCWSecurityPersonal@5$kCWSecurityWEP@1$kCWSecurityWPA2Enterprise@9$kCWSecurityWPA2Personal@4$kCWSecurityWPA3Enterprise@12$kCWSecurityWPA3Personal@11$kCWSecurityWPA3Transition@13$kCWSecurityWPAEnterprise@7$kCWSecurityWPAEnterpriseMixed@8$kCWSecurityWPAPersonal@2$kCWSecurityWPAPersonalMixed@3$kCWShortSlotUnsupportedErr@-3915$kCWSupplicantTimeoutErr@-3925$kCWTimeoutErr@-3905$kCWUknownErr@-3902$kCWUnknownErr@-3902$kCWUnspecifiedFailureErr@-3906$kCWUnsupportedCapabilitiesErr@-3907$kCWUnsupportedRSNVersionErr@-3921$kCWUnsupportedRateSetErr@-3914$"""
misc.update(
    {
        "kCWSecurityUnknown": sel32or64(2147483647, 9223372036854775807),
        "CWEventTypeUnknown": sel32or64(2147483647, 9223372036854775807),
    }
)
misc.update({})
functions = {
    "CWKeychainFindWiFiPassword": (
        sel32or64(b"li@^@", b"iq@^@"),
        "",
        {"arguments": {2: {"type_modifier": "o"}}},
    ),
    "CWKeychainSetEAPIdentity": (
        sel32or64(
            b"l^{__CFData=}^{OpaqueSecIdentityRef=}", b"i^{__CFData=}^{__SecIdentity=}"
        ),
    ),
    "CWKeychainSetEAPUsernameAndPassword": (
        sel32or64(
            b"l^{__CFData=}^{__CFString=}^{__CFString=}",
            b"i^{__CFData=}^{__CFString=}^{__CFString=}",
        ),
    ),
    "CWKeychainDeleteWiFiEAPUsernameAndPassword": (sel32or64(b"li@", b"iq@"),),
    "CWKeychainDeletePassword": (sel32or64(b"l^{__CFData=}", b"i^{__CFData=}"),),
    "CWKeychainCopyEAPIdentityList": (
        sel32or64(b"l^^{__CFArray=}", b"i^^{__CFArray=}"),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {0: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "CWKeychainCopyWiFiEAPIdentity": (
        sel32or64(b"li@^^{OpaqueSecIdentityRef=}", b"iq@^^{__SecIdentity=}"),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "CWKeychainSetWiFiEAPUsernameAndPassword": (sel32or64(b"li@@@", b"iq@@@"),),
    "CWKeychainFindWiFiEAPUsernameAndPassword": (
        sel32or64(b"li@^@^@", b"iq@^@^@"),
        "",
        {"arguments": {2: {"type_modifier": "o"}, 3: {"type_modifier": "o"}}},
    ),
    "CWKeychainCopyEAPUsernameAndPassword": (
        sel32or64(
            b"l^{__CFData=}^^{__CFString=}^^{__CFString=}",
            b"i^{__CFData=}^^{__CFString=}^^{__CFString=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {"already_cfretained": True, "type_modifier": "o"},
                2: {"already_cfretained": True, "type_modifier": "o"},
            },
        },
    ),
    "CWKeychainSetPassword": (
        sel32or64(b"l^{__CFData=}^{__CFString=}", b"i^{__CFData=}^{__CFString=}"),
    ),
    "CWKeychainCopyPassword": (
        sel32or64(b"l^{__CFData=}^^{__CFString=}", b"i^{__CFData=}^^{__CFString=}"),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "CWKeychainDeleteEAPUsernameAndPassword": (
        sel32or64(b"l^{__CFData=}", b"i^{__CFData=}"),
    ),
    "CWKeychainCopyEAPIdentity": (
        sel32or64(
            b"l^{__CFData=}^^{OpaqueSecIdentityRef=}",
            b"i^{__CFData=}^^{__SecIdentity=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "CWKeychainDeleteWiFiPassword": (sel32or64(b"li@", b"iq@"),),
    "CWMergeNetworks": (b"@@",),
    "CWKeychainSetWiFiPassword": (sel32or64(b"li@@", b"iq@@"),),
    "CWKeychainSetWiFiEAPIdentity": (
        sel32or64(b"li@^{OpaqueSecIdentityRef=}", b"iq@^{__SecIdentity=}"),
    ),
}
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(b"CW8021XProfile", b"alwaysPromptForPassword", {"retval": {"type": b"Z"}})
    r(b"CW8021XProfile", b"isEqualToProfile:", {"retval": {"type": b"Z"}})
    r(
        b"CW8021XProfile",
        b"setAlwaysPromptForPassword:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"CWChannel", b"isEqualToChannel:", {"retval": {"type": b"Z"}})
    r(b"CWConfiguration", b"alwaysRememberNetworks", {"retval": {"type": b"Z"}})
    r(b"CWConfiguration", b"disconnectOnLogout", {"retval": {"type": b"Z"}})
    r(b"CWConfiguration", b"isEqualToConfiguration:", {"retval": {"type": b"Z"}})
    r(b"CWConfiguration", b"rememberJoinedNetworks", {"retval": {"type": b"Z"}})
    r(b"CWConfiguration", b"requireAdminForIBSSCreation", {"retval": {"type": b"Z"}})
    r(b"CWConfiguration", b"requireAdminForNetworkChange", {"retval": {"type": b"Z"}})
    r(b"CWConfiguration", b"requireAdminForPowerChange", {"retval": {"type": b"Z"}})
    r(
        b"CWConfiguration",
        b"requireAdministratorForAssociation",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"CWConfiguration",
        b"requireAdministratorForIBSSMode",
        {"retval": {"type": b"Z"}},
    )
    r(b"CWConfiguration", b"requireAdministratorForPower", {"retval": {"type": b"Z"}})
    r(
        b"CWConfiguration",
        b"setAlwaysRememberNetworks:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"CWConfiguration", b"setDisconnectOnLogout:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"CWConfiguration",
        b"setRememberJoinedNetworks:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"CWConfiguration",
        b"setRequireAdminForIBSSCreation:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"CWConfiguration",
        b"setRequireAdminForNetworkChange:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"CWConfiguration",
        b"setRequireAdminForPowerChange:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"CWConfiguration",
        b"setRequireAdministratorForAssociation:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"CWConfiguration",
        b"setRequireAdministratorForIBSSMode:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"CWConfiguration",
        b"setRequireAdministratorForPower:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"CWInterface",
        b"associateToEnterpriseNetwork:identity:username:password:error:",
        {"retval": {"type": b"Z"}, "arguments": {6: {"type_modifier": b"o"}}},
    )
    r(
        b"CWInterface",
        b"associateToNetwork:parameters:error:",
        {"retval": {"type": b"Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"CWInterface",
        b"associateToNetwork:password:error:",
        {"retval": {"type": b"Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"CWInterface",
        b"commitConfiguration:authorization:error:",
        {"retval": {"type": b"Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"CWInterface",
        b"commitConfiguration:error:",
        {"retval": {"type": b"Z"}, "arguments": {3: {"type_modifier": b"o"}}},
    )
    r(b"CWInterface", b"deviceAttached", {"retval": {"type": b"Z"}})
    r(
        b"CWInterface",
        b"enableIBSSWithParameters:error:",
        {"retval": {"type": b"Z"}, "arguments": {3: {"type_modifier": b"o"}}},
    )
    r(b"CWInterface", b"isEqualToInterface:", {"retval": {"type": b"Z"}})
    r(b"CWInterface", b"power", {"retval": {"type": b"Z"}})
    r(b"CWInterface", b"powerOn", {"retval": {"type": b"Z"}})
    r(b"CWInterface", b"powerSave", {"retval": {"type": b"Z"}})
    r(
        b"CWInterface",
        b"scanForNetworksWithName:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"CWInterface",
        b"scanForNetworksWithName:includeHidden:error:",
        {"arguments": {3: {"type": "Z"}, 4: {"type_modifier": b"o"}}},
    )
    r(
        b"CWInterface",
        b"scanForNetworksWithParameters:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"CWInterface",
        b"scanForNetworksWithSSID:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"CWInterface",
        b"scanForNetworksWithSSID:includeHidden:error:",
        {"arguments": {3: {"type": "Z"}, 4: {"type_modifier": b"o"}}},
    )
    r(b"CWInterface", b"serviceActive", {"retval": {"type": b"Z"}})
    r(
        b"CWInterface",
        b"setChannel:error:",
        {"retval": {"type": b"Z"}, "arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"CWInterface",
        b"setPairwiseMasterKey:error:",
        {"retval": {"type": b"Z"}, "arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"CWInterface",
        b"setPower:error:",
        {
            "retval": {"type": b"Z"},
            "arguments": {2: {"type": b"Z"}, 3: {"type_modifier": b"o"}},
        },
    )
    r(
        b"CWInterface",
        b"setWEPKey:flags:index:error:",
        {"retval": {"type": b"Z"}, "arguments": {5: {"type_modifier": b"o"}}},
    )
    r(
        b"CWInterface",
        b"setWLANChannel:error:",
        {"retval": {"type": b"Z"}, "arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"CWInterface",
        b"startIBSSModeWithSSID:security:channel:password:error:",
        {"retval": {"type": b"Z"}, "arguments": {6: {"type_modifier": b"o"}}},
    )
    r(b"CWInterface", b"supportsAES_CCM", {"retval": {"type": b"Z"}})
    r(b"CWInterface", b"supportsHostAP", {"retval": {"type": b"Z"}})
    r(b"CWInterface", b"supportsIBSS", {"retval": {"type": b"Z"}})
    r(b"CWInterface", b"supportsMonitorMode", {"retval": {"type": b"Z"}})
    r(b"CWInterface", b"supportsPMGT", {"retval": {"type": b"Z"}})
    r(b"CWInterface", b"supportsShortGI20MHz", {"retval": {"type": b"Z"}})
    r(b"CWInterface", b"supportsShortGI40MHz", {"retval": {"type": b"Z"}})
    r(b"CWInterface", b"supportsTKIP", {"retval": {"type": b"Z"}})
    r(b"CWInterface", b"supportsTSN", {"retval": {"type": b"Z"}})
    r(b"CWInterface", b"supportsWEP", {"retval": {"type": b"Z"}})
    r(b"CWInterface", b"supportsWME", {"retval": {"type": b"Z"}})
    r(b"CWInterface", b"supportsWPA", {"retval": {"type": b"Z"}})
    r(b"CWInterface", b"supportsWPA2", {"retval": {"type": b"Z"}})
    r(b"CWInterface", b"supportsWoW", {"retval": {"type": b"Z"}})
    r(b"CWMutableConfiguration", b"rememberJoinedNetworks", {"retval": {"type": b"Z"}})
    r(
        b"CWMutableConfiguration",
        b"requireAdministratorForAssociation",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"CWMutableConfiguration",
        b"requireAdministratorForIBSSMode",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"CWMutableConfiguration",
        b"requireAdministratorForPower",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"CWMutableConfiguration",
        b"setRememberJoinedNetworks:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"CWMutableConfiguration",
        b"setRequireAdministratorForAssociation:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"CWMutableConfiguration",
        b"setRequireAdministratorForIBSSMode:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"CWMutableConfiguration",
        b"setRequireAdministratorForPower:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"CWNetwork", b"ibss", {"retval": {"type": b"Z"}})
    r(b"CWNetwork", b"isEqualToNetwork:", {"retval": {"type": b"Z"}})
    r(b"CWNetwork", b"isIBSS", {"retval": {"type": b"Z"}})
    r(b"CWNetwork", b"supportsPHYMode:", {"retval": {"type": b"Z"}})
    r(b"CWNetwork", b"supportsSecurity:", {"retval": {"type": b"Z"}})
    r(b"CWNetworkProfile", b"isEqualToNetworkProfile:", {"retval": {"type": b"Z"}})
    r(
        b"CWWiFiClient",
        b"startMonitoringEventWithType:error:",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"CWWiFiClient",
        b"stopMonitoringAllEventsAndReturnError:",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"CWWiFiClient",
        b"stopMonitoringEventWithType:error:",
        {"retval": {"type": b"Z"}},
    )
    r(b"CWWirelessProfile", b"isEqualToProfile:", {"retval": {"type": b"Z"}})
    r(
        b"NSObject",
        b"bssidDidChangeForWiFiInterfaceWithName:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"clientConnectionInterrupted",
        {"required": False, "retval": {"type": b"v"}},
    )
    r(
        b"NSObject",
        b"clientConnectionInvalidated",
        {"required": False, "retval": {"type": b"v"}},
    )
    r(
        b"NSObject",
        b"countryCodeDidChangeForWiFiInterfaceWithName:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"linkDidChangeForWiFiInterfaceWithName:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"linkQualityDidChangeForWiFiInterfaceWithName:rssi:transmitRate:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": sel32or64(b"i", b"q")},
                4: {"type": b"d"},
            },
        },
    )
    r(
        b"NSObject",
        b"modeDidChangeForWiFiInterfaceWithName:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"powerStateDidChangeForWiFiInterfaceWithName:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"scanCacheUpdatedForWiFiInterfaceWithName:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"ssidDidChangeForWiFiInterfaceWithName:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



import CoreWLAN
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCW8021XProfile(TestCase):
    @min_os_level("10.6")
    def testMethods10_6(self):
        self.assertResultIsBOOL(CoreWLAN.CW8021XProfile.alwaysPromptForPassword)
        self.assertArgIsBOOL(CoreWLAN.CW8021XProfile.setAlwaysPromptForPassword_, 0)
        self.assertResultIsBOOL(CoreWLAN.CW8021XProfile.isEqualToProfile_)

    @min_os_level("10.6")
    def testConvenience(self):
        p1 = CoreWLAN.CW8021XProfile.profile()
        p2 = CoreWLAN.CW8021XProfile.profile()

        self.assertTrue(p1 == p1)
        self.assertFalse(p1 != p1)
        self.assertTrue(p1 != p2)

        self.assertFalse(p1 == 42)
        self.assertTrue(p1 != 42)



import CoreWLAN
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCoreWLANConstants(TestCase):
    @min_os_level("10.7")
    def testConstants10_7(self):
        self.assertIsInstance(CoreWLAN.CWErrorDomain, str)
        self.assertIsInstance(CoreWLAN.CWScanCacheDidUpdateNotification, str)
        self.assertIsInstance(CoreWLAN.CWLinkQualityDidChangeNotification, str)
        self.assertIsInstance(CoreWLAN.CWLinkQualityNotificationRSSIKey, str)
        self.assertIsInstance(CoreWLAN.CWLinkQualityNotificationTransmitRateKey, str)
        self.assertIsInstance(CoreWLAN.CWServiceDidChangeNotification, str)

        self.assertIsInstance(CoreWLAN.CWPowerDidChangeNotification, str)
        self.assertIsInstance(CoreWLAN.CWSSIDDidChangeNotification, str)
        self.assertIsInstance(CoreWLAN.CWBSSIDDidChangeNotification, str)
        self.assertIsInstance(CoreWLAN.CWLinkDidChangeNotification, str)
        self.assertIsInstance(CoreWLAN.CWModeDidChangeNotification, str)
        self.assertIsInstance(CoreWLAN.CWCountryCodeDidChangeNotification, str)

    @min_os_level("10.6")
    def testConstants10_6(self):
        self.assertIsInstance(CoreWLAN.kCWErrorDomain, str)
        self.assertIsInstance(CoreWLAN.kCWPowerDidChangeNotification, str)
        self.assertIsInstance(CoreWLAN.kCWSSIDDidChangeNotification, str)
        self.assertIsInstance(CoreWLAN.kCWBSSIDDidChangeNotification, str)
        self.assertIsInstance(CoreWLAN.kCWLinkDidChangeNotification, str)
        self.assertIsInstance(CoreWLAN.kCWModeDidChangeNotification, str)
        self.assertIsInstance(CoreWLAN.kCWCountryCodeDidChangeNotification, str)
        self.assertIsInstance(CoreWLAN.kCWAssocKeyPassphrase, str)
        self.assertIsInstance(CoreWLAN.kCWAssocKey8021XProfile, str)
        self.assertIsInstance(CoreWLAN.kCWIBSSKeySSID, str)
        self.assertIsInstance(CoreWLAN.kCWIBSSKeyChannel, str)
        self.assertIsInstance(CoreWLAN.kCWIBSSKeyPassphrase, str)
        self.assertIsInstance(CoreWLAN.kCWScanKeySSID, str)
        self.assertIsInstance(CoreWLAN.kCWScanKeyBSSID, str)
        self.assertIsInstance(CoreWLAN.kCWScanKeyMerge, str)
        self.assertIsInstance(CoreWLAN.kCWScanKeyScanType, str)
        self.assertIsInstance(CoreWLAN.kCWScanKeyDwellTime, str)
        self.assertIsInstance(CoreWLAN.kCWScanKeyRestTime, str)



import CoreWLAN
import Foundation
from PyObjCTools.TestSupport import TestCase


class TestCoreWLANTypes(TestCase):
    def testConstants(self):
        self.assertEqual(CoreWLAN.kCWNoErr, 0)
        self.assertEqual(CoreWLAN.kCWEAPOLErr, 1)
        self.assertEqual(CoreWLAN.kCWInvalidParameterErr, -3900)
        self.assertEqual(CoreWLAN.kCWNoMemoryErr, -3901)
        self.assertEqual(CoreWLAN.kCWUnknownErr, -3902)
        self.assertEqual(CoreWLAN.kCWNotSupportedErr, -3903)
        self.assertEqual(CoreWLAN.kCWInvalidFormatErr, -3904)
        self.assertEqual(CoreWLAN.kCWTimeoutErr, -3905)
        self.assertEqual(CoreWLAN.kCWUnspecifiedFailureErr, -3906)
        self.assertEqual(CoreWLAN.kCWUnsupportedCapabilitiesErr, -3907)
        self.assertEqual(CoreWLAN.kCWReassociationDeniedErr, -3908)
        self.assertEqual(CoreWLAN.kCWAssociationDeniedErr, -3909)
        self.assertEqual(CoreWLAN.kCWAuthenticationAlgorithmUnsupportedErr, -3910)
        self.assertEqual(CoreWLAN.kCWInvalidAuthenticationSequenceNumberErr, -3911)
        self.assertEqual(CoreWLAN.kCWChallengeFailureErr, -3912)
        self.assertEqual(CoreWLAN.kCWAPFullErr, -3913)
        self.assertEqual(CoreWLAN.kCWUnsupportedRateSetErr, -3914)
        self.assertEqual(CoreWLAN.kCWShortSlotUnsupportedErr, -3915)
        self.assertEqual(CoreWLAN.kCWDSSSOFDMUnsupportedErr, -3916)
        self.assertEqual(CoreWLAN.kCWInvalidInformationElementErr, -3917)
        self.assertEqual(CoreWLAN.kCWInvalidGroupCipherErr, -3918)
        self.assertEqual(CoreWLAN.kCWInvalidPairwiseCipherErr, -3919)
        self.assertEqual(CoreWLAN.kCWInvalidAKMPErr, -3920)
        self.assertEqual(CoreWLAN.kCWUnsupportedRSNVersionErr, -3921)
        self.assertEqual(CoreWLAN.kCWInvalidRSNCapabilitiesErr, -3922)
        self.assertEqual(CoreWLAN.kCWCipherSuiteRejectedErr, -3923)
        self.assertEqual(CoreWLAN.kCWInvalidPMKErr, -3924)
        self.assertEqual(CoreWLAN.kCWSupplicantTimeoutErr, -3925)
        self.assertEqual(CoreWLAN.kCWHTFeaturesNotSupportedErr, -3926)
        self.assertEqual(CoreWLAN.kCWPCOTransitionTimeNotSupportedErr, -3927)
        self.assertEqual(CoreWLAN.kCWReferenceNotBoundErr, -3928)
        self.assertEqual(CoreWLAN.kCWIPCFailureErr, -3929)
        self.assertEqual(CoreWLAN.kCWOperationNotPermittedErr, -3930)
        self.assertEqual(CoreWLAN.kCWErr, -3931)
        self.assertEqual(CoreWLAN.kCWPHYModeNone, 0)
        self.assertEqual(CoreWLAN.kCWPHYMode11a, 1)
        self.assertEqual(CoreWLAN.kCWPHYMode11b, 2)
        self.assertEqual(CoreWLAN.kCWPHYMode11g, 3)
        self.assertEqual(CoreWLAN.kCWPHYMode11n, 4)
        self.assertEqual(CoreWLAN.kCWPHYMode11ac, 5)
        self.assertEqual(CoreWLAN.kCWInterfaceModeNone, 0)
        self.assertEqual(CoreWLAN.kCWInterfaceModeStation, 1)
        self.assertEqual(CoreWLAN.kCWInterfaceModeIBSS, 2)
        self.assertEqual(CoreWLAN.kCWInterfaceModeHostAP, 3)
        self.assertEqual(CoreWLAN.kCWSecurityNone, 0)
        self.assertEqual(CoreWLAN.kCWSecurityWEP, 1)
        self.assertEqual(CoreWLAN.kCWSecurityWPAPersonal, 2)
        self.assertEqual(CoreWLAN.kCWSecurityWPAPersonalMixed, 3)
        self.assertEqual(CoreWLAN.kCWSecurityWPA2Personal, 4)
        self.assertEqual(CoreWLAN.kCWSecurityPersonal, 5)
        self.assertEqual(CoreWLAN.kCWSecurityDynamicWEP, 6)
        self.assertEqual(CoreWLAN.kCWSecurityWPAEnterprise, 7)
        self.assertEqual(CoreWLAN.kCWSecurityWPAEnterpriseMixed, 8)
        self.assertEqual(CoreWLAN.kCWSecurityWPA2Enterprise, 9)
        self.assertEqual(CoreWLAN.kCWSecurityEnterprise, 10)
        self.assertEqual(CoreWLAN.kCWSecurityWPA3Personal, 11)
        self.assertEqual(CoreWLAN.kCWSecurityWPA3Enterprise, 12)
        self.assertEqual(CoreWLAN.kCWSecurityWPA3Transition, 13)
        self.assertEqual(CoreWLAN.kCWSecurityUnknown, Foundation.NSIntegerMax)
        self.assertEqual(CoreWLAN.kCWIBSSModeSecurityNone, 0)
        self.assertEqual(CoreWLAN.kCWIBSSModeSecurityWEP40, 1)
        self.assertEqual(CoreWLAN.kCWIBSSModeSecurityWEP104, 2)
        self.assertEqual(CoreWLAN.kCWChannelWidthUnknown, 0)
        self.assertEqual(CoreWLAN.kCWChannelWidth20MHz, 1)
        self.assertEqual(CoreWLAN.kCWChannelWidth40MHz, 2)
        self.assertEqual(CoreWLAN.kCWChannelWidth80MHz, 3)
        self.assertEqual(CoreWLAN.kCWChannelWidth160MHz, 4)
        self.assertEqual(CoreWLAN.kCWChannelBandUnknown, 0)
        self.assertEqual(CoreWLAN.kCWChannelBand2GHz, 1)
        self.assertEqual(CoreWLAN.kCWChannelBand5GHz, 2)
        self.assertEqual(CoreWLAN.kCWCipherKeyFlagsNone, 0)
        self.assertEqual(CoreWLAN.kCWCipherKeyFlagsUnicast, 1 << 1)
        self.assertEqual(CoreWLAN.kCWCipherKeyFlagsMulticast, 1 << 2)
        self.assertEqual(CoreWLAN.kCWCipherKeyFlagsTx, 1 << 3),
        self.assertEqual(CoreWLAN.kCWCipherKeyFlagsRx, 1 << 4),
        self.assertEqual(CoreWLAN.kCWParamErr, CoreWLAN.kCWInvalidParameterErr)
        self.assertEqual(CoreWLAN.kCWNoMemErr, CoreWLAN.kCWNoMemoryErr)
        self.assertEqual(CoreWLAN.kCWUknownErr, CoreWLAN.kCWUnknownErr)
        self.assertEqual(CoreWLAN.kCWFormatErr, CoreWLAN.kCWInvalidFormatErr)
        self.assertEqual(
            CoreWLAN.kCWAuthAlgUnsupportedErr,
            CoreWLAN.kCWAuthenticationAlgorithmUnsupportedErr,
        )
        self.assertEqual(
            CoreWLAN.kCWInvalidAuthSeqNumErr,
            CoreWLAN.kCWInvalidAuthenticationSequenceNumberErr,
        )
        self.assertEqual(
            CoreWLAN.kCWInvalidInfoElementErr, CoreWLAN.kCWInvalidInformationElementErr
        )
        self.assertEqual(
            CoreWLAN.kCWHTFeaturesNotSupported, CoreWLAN.kCWHTFeaturesNotSupportedErr
        )
        self.assertEqual(
            CoreWLAN.kCWPCOTransitionTimeNotSupported,
            CoreWLAN.kCWPCOTransitionTimeNotSupportedErr,
        )
        self.assertEqual(CoreWLAN.kCWRefNotBoundErr, CoreWLAN.kCWReferenceNotBoundErr)
        self.assertEqual(CoreWLAN.kCWIPCError, CoreWLAN.kCWIPCFailureErr)
        self.assertEqual(
            CoreWLAN.kCWOpNotPermitted, CoreWLAN.kCWOperationNotPermittedErr
        )
        self.assertEqual(CoreWLAN.kCWError, CoreWLAN.kCWErr)
        self.assertEqual(CoreWLAN.kCWPHYMode11A, 0)
        self.assertEqual(CoreWLAN.kCWPHYMode11B, 1)
        self.assertEqual(CoreWLAN.kCWPHYMode11G, 2)
        self.assertEqual(CoreWLAN.kCWPHYMode11N, 3)
        self.assertEqual(CoreWLAN.kCWOpModeStation, 0)
        self.assertEqual(CoreWLAN.kCWOpModeIBSS, 1)
        self.assertEqual(CoreWLAN.kCWOpModeHostAP, 2)
        self.assertEqual(CoreWLAN.kCWOpModeMonitorMode, 3)
        self.assertEqual(CoreWLAN.kCWSecurityModeOpen, 0)
        self.assertEqual(CoreWLAN.kCWSecurityModeWEP, 1)
        self.assertEqual(CoreWLAN.kCWSecurityModeWPA_PSK, 2)
        self.assertEqual(CoreWLAN.kCWSecurityModeWPA2_PSK, 3)
        self.assertEqual(CoreWLAN.kCWSecurityModeDynamicWEP, 4)
        self.assertEqual(CoreWLAN.kCWSecurityModeWPA_Enterprise, 5)
        self.assertEqual(CoreWLAN.kCWSecurityModeWPA2_Enterprise, 6)
        self.assertEqual(CoreWLAN.kCWSecurityModeWPS, 7)
        self.assertEqual(CoreWLAN.kCWInterfaceStateInactive, 0)
        self.assertEqual(CoreWLAN.kCWInterfaceStateScanning, 1)
        self.assertEqual(CoreWLAN.kCWInterfaceStateAuthenticating, 2)
        self.assertEqual(CoreWLAN.kCWInterfaceStateAssociating, 3)
        self.assertEqual(CoreWLAN.kCWInterfaceStateRunning, 4)
        self.assertEqual(CoreWLAN.kCWScanTypeActive, 0)
        self.assertEqual(CoreWLAN.kCWScanTypePassive, 1)
        self.assertEqual(CoreWLAN.kCWScanTypeFast, 2)
        self.assertEqual(CoreWLAN.kCWKeychainDomainNone, 0)
        self.assertEqual(CoreWLAN.kCWKeychainDomainUser, 1)
        self.assertEqual(CoreWLAN.kCWKeychainDomainSystem, 2)
        self.assertEqual(CoreWLAN.CWEventTypeNone, 0)
        self.assertEqual(CoreWLAN.CWEventTypePowerDidChange, 1)
        self.assertEqual(CoreWLAN.CWEventTypeSSIDDidChange, 2)
        self.assertEqual(CoreWLAN.CWEventTypeBSSIDDidChange, 3)
        self.assertEqual(CoreWLAN.CWEventTypeCountryCodeDidChange, 4)
        self.assertEqual(CoreWLAN.CWEventTypeLinkDidChange, 5)
        self.assertEqual(CoreWLAN.CWEventTypeLinkQualityDidChange, 6)
        self.assertEqual(CoreWLAN.CWEventTypeModeDidChange, 7)
        self.assertEqual(CoreWLAN.CWEventTypeScanCacheUpdated, 8)
        self.assertEqual(CoreWLAN.CWEventTypeUnknown, Foundation.NSIntegerMax)

        # Introduced in 10.12
        self.assertEqual(CoreWLAN.CWEventTypeVirtualInterfaceStateChanged, 9)
        self.assertEqual(CoreWLAN.CWEventTypeRangingReportEvent, 10)



"""
Python mapping for the CoreWLAN framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Foundation
import objc
from CoreWLAN import _CoreWLAN, _metadata


def _CW8021XProfile__eq__(self, other):
    if not isinstance(other, type(self)):
        return False

    return self.isEqualToProfile_(other)


def _CW8021XProfile__ne__(self, other):
    if not isinstance(other, type(self)):
        return True

    return not self.isEqualToProfile_(other)


objc.addConvenienceForClass(
    "CW8021XProfile",
    (("__eq__", _CW8021XProfile__eq__), ("__ne__", _CW8021XProfile__ne__)),
)


def _CWChannel__eq__(self, other):
    if not isinstance(other, type(self)):
        return False

    return self.isEqualToChannel_(other)


def _CWChannel__ne__(self, other):
    if not isinstance(other, type(self)):
        return True

    return not self.isEqualToChannel_(other)


objc.addConvenienceForClass(
    "CWChannel", (("__eq__", _CWChannel__eq__), ("__ne__", _CWChannel__ne__))
)


def _CWConfiguration__eq__(self, other):
    if not isinstance(other, type(self)):
        return False

    return self.isEqualToConfiguration_(other)


def _CWConfiguration__ne__(self, other):
    if not isinstance(other, type(self)):
        return True

    return not self.isEqualToConfiguration_(other)


objc.addConvenienceForClass(
    "CWConfiguration",
    (("__eq__", _CWConfiguration__eq__), ("__ne__", _CWConfiguration__ne__)),
)


def _CWNetwork__eq__(self, other):
    if not isinstance(other, type(self)):
        return False

    return self.isEqualToNetwork_(other)


def _CWNetwork__ne__(self, other):
    if not isinstance(other, type(self)):
        return True

    return not self.isEqualToNetwork_(other)


objc.addConvenienceForClass(
    "CWNetwork", (("__eq__", _CWNetwork__eq__), ("__ne__", _CWNetwork__ne__))
)


def _CWNetworkProfile__eq__(self, other):
    if not isinstance(other, type(self)):
        return False

    return self.isEqualToNetworkProfile_(other)


def _CWNetworkProfile__ne__(self, other):
    if not isinstance(other, type(self)):
        return True

    return not self.isEqualToNetworkProfile_(other)


objc.addConvenienceForClass(
    "CWNetworkProfile",
    (("__eq__", _CWNetworkProfile__eq__), ("__ne__", _CWNetworkProfile__ne__)),
)


sys.modules["CoreWLAN"] = mod = objc.ObjCLazyModule(
    "CoreWLAN",
    "com.apple.framework.CoreWLAN",
    objc.pathForFramework("/System/Library/Frameworks/CoreWLAN.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_CoreWLAN, Foundation),
)


del sys.modules["CoreWLAN._metadata"]
del sys.modules["CoreWLAN._CoreWLAN"]



import CoreWLAN
from PyObjCTools.TestSupport import TestCase, min_os_level, os_level_between


class TestCWConfiguration(TestCase):
    @os_level_between("10.6", "10.8")
    def testMethods10_6(self):
        self.assertResultIsBOOL(CoreWLAN.CWConfiguration.requireAdminForNetworkChange)
        self.assertResultIsBOOL(CoreWLAN.CWConfiguration.requireAdminForPowerChange)
        self.assertResultIsBOOL(CoreWLAN.CWConfiguration.requireAdminForIBSSCreation)

        self.assertArgIsBOOL(
            CoreWLAN.CWConfiguration.setRequireAdminForNetworkChange_, 0
        )
        self.assertArgIsBOOL(CoreWLAN.CWConfiguration.setRequireAdminForPowerChange_, 0)
        self.assertArgIsBOOL(
            CoreWLAN.CWConfiguration.setRequireAdminForIBSSCreation_, 0
        )

        self.assertResultIsBOOL(CoreWLAN.CWConfiguration.alwaysRememberNetworks)
        self.assertArgIsBOOL(CoreWLAN.CWConfiguration.setAlwaysRememberNetworks_, 0)

        self.assertResultIsBOOL(CoreWLAN.CWConfiguration.disconnectOnLogout)
        self.assertArgIsBOOL(CoreWLAN.CWConfiguration.setDisconnectOnLogout_, 0)

    @min_os_level("10.7")
    def testMethods10_7(self):
        self.assertResultIsBOOL(
            CoreWLAN.CWConfiguration.requireAdministratorForAssociation
        )
        self.assertResultIsBOOL(CoreWLAN.CWConfiguration.requireAdministratorForPower)
        self.assertResultIsBOOL(
            CoreWLAN.CWConfiguration.requireAdministratorForIBSSMode
        )
        self.assertResultIsBOOL(CoreWLAN.CWConfiguration.rememberJoinedNetworks)
        self.assertResultIsBOOL(CoreWLAN.CWConfiguration.isEqualToConfiguration_)

        self.assertArgIsBOOL(
            CoreWLAN.CWMutableConfiguration.setRequireAdministratorForAssociation_, 0
        )
        self.assertArgIsBOOL(
            CoreWLAN.CWMutableConfiguration.setRequireAdministratorForPower_, 0
        )
        self.assertArgIsBOOL(
            CoreWLAN.CWMutableConfiguration.setRequireAdministratorForIBSSMode_, 0
        )
        self.assertArgIsBOOL(
            CoreWLAN.CWMutableConfiguration.setRememberJoinedNetworks_, 0
        )

    @min_os_level("10.6")
    def testConvenience(self):
        c1 = CoreWLAN.CWConfiguration.alloc().init()
        c2 = CoreWLAN.CWConfiguration.alloc().init()

        self.assertTrue(c1 == c2)
        self.assertFalse(c1 != c2)

        self.assertFalse(c1 == 42)
        self.assertTrue(c1 != 42)



#!/usr/bin/env python
"""
A simple script for toggling the power to the WLAN adaptor

NOTE: Running this script might require administrator
      privileges (depending on the macOS settings)
"""

import sys

import CoreWLAN

iface = CoreWLAN.CWInterface.interface()

ok, error = iface.setPower_error_(not iface.powerOn(), None)
if ok:
    print(
        "Toggled WLAN power, current state is %s"
        % ("on" if iface.powerOn() else "off",)
    )

    sys.exit(0)
else:
    print("Could not toggle WLAN power: %s" % (error.localizedDescription(),))

    sys.exit(1)



import CoreWLAN
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCWChannel(TestCase):
    @min_os_level("10.7")
    def testMethods(self):
        self.assertResultIsBOOL(CoreWLAN.CWChannel.isEqualToChannel_)

    @min_os_level("10.7")
    def testConvenience(self):
        c1 = CoreWLAN.CWChannel.alloc().init()
        c2 = CoreWLAN.CWChannel.alloc().init()

        self.assertTrue(c1 == c2)
        self.assertFalse(c1 != c2)

        self.assertFalse(c1 == 42)
        self.assertTrue(c1 != 42)



import CoreWLAN
from PyObjCTools.TestSupport import TestCase, min_os_level, expectedFailure


class TestCWNetwork(TestCase):
    @min_os_level("10.7")
    def test_methods10_7(self):
        self.assertResultIsBOOL(CoreWLAN.CWNetwork.ibss)

        self.assertResultIsBOOL(CoreWLAN.CWNetwork.supportsSecurity_)
        self.assertResultIsBOOL(CoreWLAN.CWNetwork.supportsPHYMode_)

    @min_os_level("10.6")
    def test_methods10_6(self):
        self.assertResultIsBOOL(CoreWLAN.CWNetwork.isEqualToNetwork_)
        self.assertResultIsBOOL(CoreWLAN.CWNetwork.isIBSS)

    @min_os_level("10.7")
    @expectedFailure  # on 10.15
    def testConvenience(self):
        c1 = CoreWLAN.CWNetwork.alloc().init()
        c2 = CoreWLAN.CWNetwork.alloc().init()

        self.assertTrue(c1 == c2)
        self.assertFalse(c1 != c2)

        self.assertFalse(c1 == 42)
        self.assertTrue(c1 != 42)



import CoreWLAN
import objc
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCWWifiClientHelper(CoreWLAN.NSObject):
    def linkQualityDidChangeForWiFiInterfaceWithName_rssi_transmitRate_(
        self, nm, rs, tr
    ):
        pass


class TestCWWiFiClient(TestCase):
    @min_os_level("10.10")
    def testProtocols10_10(self):
        self.assertIsInstance(
            objc.protocolNamed("CWEventDelegate"), objc.formal_protocol
        )

        self.assertArgHasType(
            TestCWWifiClientHelper.linkQualityDidChangeForWiFiInterfaceWithName_rssi_transmitRate_,  # noqa: B950
            1,
            objc._C_NSInteger,
            objc._C_DBL,
        )

    @min_os_level("10.10")
    def testMethods10_10(self):
        self.assertResultIsBOOL(
            CoreWLAN.CWWiFiClient.startMonitoringEventWithType_error_
        )
        self.assertArgIsOut(
            CoreWLAN.CWWiFiClient.startMonitoringEventWithType_error_, 1
        )

        self.assertResultIsBOOL(
            CoreWLAN.CWWiFiClient.stopMonitoringEventWithType_error_
        )
        self.assertArgIsOut(CoreWLAN.CWWiFiClient.stopMonitoringEventWithType_error_, 1)

        self.assertResultIsBOOL(
            CoreWLAN.CWWiFiClient.stopMonitoringAllEventsAndReturnError_
        )
        self.assertArgIsOut(
            CoreWLAN.CWWiFiClient.stopMonitoringAllEventsAndReturnError_, 0
        )



import CoreWLAN
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCWWirelessProfile(TestCase):
    @min_os_level("10.6")
    def test_methods10_6(self):
        self.assertResultIsBOOL(CoreWLAN.CWWirelessProfile.isEqualToProfile_)



import CoreWLAN
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCoreWLAN(TestCase):
    @min_os_level("10.7")
    def testConstants(self):
        self.assertEqual(CoreWLAN.CoreWLANFrameworkVersionNumber2_0, 200)
        self.assertIsInstance(CoreWLAN.CoreWLANFrameworkVersionNumber, float)
